-- ----------------- FILE: SELECT01.SQL -------------------
-- -                                                      - 
-- -          Validates SELECT statement	          -
-- -                                                      -
-- --------------------------------------------------------
--

-- --------------------------------------------------------
-- This set of test cases validates the simplest queries.
-- This test the column data at 3 positions: begining, middle
-- and end.
-- This also test the limit value.
-- It tries also to validate some overflow or underflow cases
-- --------------------------------------------------------
-- --------------------------------------------------------
-- Delete tables
-- --------------------------------------------------------
DROP TABLE tI;
DROP TABLE tS;
DROP TABLE tE;
DROP TABLE tC;
DROP TABLE tV;
DROP TABLE tB;
DROP TABLE tD;
DROP TABLE tT;

-- --------------------------------------------------------
-- INITIALIZE THE TABLES
-- --------------------------------------------------------
CREATE TABLE tI (c1 INT, c2 INT, c3 INT);
CREATE TABLE tS (c1 SMALLINT, c2 SMALLINT, c3 SMALLINT);
CREATE TABLE tE (c1 DECIMAL(15,0), c2 DECIMAL(2,2), c3 DECIMAL(15,14));
CREATE TABLE tC (c1 CHAR(5), c2 CHAR(1), c3 CHAR(254));
CREATE TABLE tV (c1 VARCHAR(7), c2 VARCHAR(1), c3 VARCHAR(1000));
CREATE TABLE tB (c1 BLOB(10), c2 BLOB(1), c3 BLOB(32767));
CREATE TABLE tD (c1 DATE, c2 DATE, c3 DATE);
CREATE TABLE tT (c1 TIME, c2 TIME, c3 TIME);

INSERT INTO tI VALUES (-1234, +1234, 1234);
INSERT INTO tI VALUES (-2147483647, +0, 2147483647);
INSERT INTO tI VALUES (+0000000000000001234, -0000, -0000000001234);

INSERT INTO tS VALUES (-1234, +1234, 1234);
INSERT INTO tS VALUES (-32767, +0, +32767);
INSERT INTO tS VALUES (+0000000000000001234, -0000, -0000000001234);

INSERT INTO tE VALUES (-1234., +.12, 1.234);
INSERT INTO tE VALUES (-999999999999999., +0.00, +9.99999999999999);
INSERT INTO tE VALUES (+0000000000000000000000000000000000001234, -.00, +0.00000000000009);

INSERT INTO tC VALUES ('1234', '', '1234');
INSERT INTO tC VALUES ('1234', '', '123456789012345678901234567890123456789012345678901234
1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890
1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890');
INSERT INTO tC VALUES ('', '', '');

INSERT INTO tV VALUES ('1234', '1', '1234567890');
INSERT INTO tV VALUES ('1234567', '\', '\\\n\0\a\d');
INSERT INTO tV VALUES ('1234', '^', '!@#$%^&*()_+<>?.\|[]{}:-=');

-- INSERT INTO tB VALUES ('1234', '1', '1234567890');
-- INSERT INTO tB VALUES ('1234567', '\', '\\\n\0\a\d');
-- INSERT INTO tB VALUES ('', '^', '!@#$%^&*()_+<>?.\|[]{}-=');

INSERT INTO tD VALUES ('08/05/1999','08/06/1999','08/07/1999');
-- INSERT INTO tD VALUES ('01/01/0001','01/01/0001','01/01/0001');
-- Year cannot be less than 100
INSERT INTO tD VALUES ('01/01/0100','01/01/0100','01/01/0100');
INSERT INTO tD VALUES ('12/31/9999','12/31/1999','12/31/0999');

INSERT INTO tT VALUES ('22:55:00','22:55:01','22:56:00');
INSERT INTO tT VALUES ('00:00:00','00:00:00','00:00:00');
INSERT INTO tT VALUES ('23:59:59','01:02:03','03:02:01');

-- ********************************************************* 
-- 3BASIC0001-3BASIC0008
-- ********************************************************* 
-- TEST:3BASIC0001-3BASIC0008 SELECT *
-- PASS:3BASIC0001-3BASIC0008 Get 3 rows with the corresponding values

SELECT * FROM tI;
SELECT * FROM tS;
SELECT * FROM tE;
SELECT * FROM tC;
SELECT * FROM tV;
SELECT * FROM tB;
SELECT * FROM tD;
SELECT * FROM tT;

-- END TEST >>> 3BASIC0001-3BASIC0008 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0009-3BASIC0032
-- ********************************************************* 
-- TEST:3BASIC0009-3BASIC0032 SELECT one column
-- PASS:3BASIC0009-3BASIC0032 Get 3 rows with the corresponding values

SELECT c1 FROM tI;
SELECT c1 FROM tS;
SELECT c1 FROM tE;
SELECT c1 FROM tC;
SELECT c1 FROM tV;
SELECT c1 FROM tB;
SELECT c1 FROM tD;
SELECT c1 FROM tT;

SELECT c2 FROM tI;
SELECT c2 FROM tS;
SELECT c2 FROM tE;
SELECT c2 FROM tC;
SELECT c2 FROM tV;
SELECT c2 FROM tB;
SELECT c2 FROM tD;
SELECT c2 FROM tT;

SELECT c3 FROM tI;
SELECT c3 FROM tS;
SELECT c3 FROM tE;
SELECT c3 FROM tC;
SELECT c3 FROM tV;
SELECT c3 FROM tB;
SELECT c3 FROM tD;
SELECT c3 FROM tT;

-- END TEST >>> 3BASIC0009-3BASIC0032 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0033-3BASIC0056
-- ********************************************************* 
-- TEST:3BASIC0033-3BASIC0056 SELECT 2 columns
-- PASS:3BASIC0033-3BASIC0056 Get 3 rows with the corresponding values

SELECT c2,c1 FROM tI;
SELECT c2,c1 FROM tS;
SELECT c2,c1 FROM tE;
SELECT c2,c1 FROM tC;
SELECT c2,c1 FROM tV;
SELECT c2,c1 FROM tB;
SELECT c2,c1 FROM tD;
SELECT c2,c1 FROM tT;

SELECT c3,c2 FROM tI;
SELECT c3,c2 FROM tS;
SELECT c3,c2 FROM tE;
SELECT c3,c2 FROM tC;
SELECT c3,c2 FROM tV;
SELECT c3,c2 FROM tB;
SELECT c3,c2 FROM tD;
SELECT c3,c2 FROM tT;

SELECT c1,c3 FROM tI;
SELECT c1,c3 FROM tS;
SELECT c1,c3 FROM tE;
SELECT c1,c3 FROM tC;
SELECT c1,c3 FROM tV;
SELECT c1,c3 FROM tB;
SELECT c1,c3 FROM tD;
SELECT c1,c3 FROM tT;

-- END TEST >>> 3BASIC0033-3BASIC0056 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0057-3BASIC0064
-- ********************************************************* 
-- TEST:3BASIC0057-3BASIC0064 SELECT 3 columns
-- PASS:3BASIC0057-3BASIC0064 Get 3 rows with the corresponding values

SELECT c2,c1,c3 FROM tI;
SELECT c2,c1,c3 FROM tS;
SELECT c2,c1,c3 FROM tE;
SELECT c2,c1,c3 FROM tC;
SELECT c2,c1,c3 FROM tV;
SELECT c2,c1,c3 FROM tB;
SELECT c2,c1,c3 FROM tD;
SELECT c2,c1,c3 FROM tT;

-- END TEST >>> 3BASIC0057-3BASIC0064 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC065-3BASIC0072
-- ********************************************************* 
-- TEST:3BASIC0065-3BASIC0072 SELECT DISTINCT *
-- PASS:3BASIC0065-3BASIC0072 Get 3 rows with the corresponding values

SELECT DISTINCT * FROM tI;
SELECT DISTINCT * FROM tS;
SELECT DISTINCT * FROM tE;
SELECT DISTINCT * FROM tC;
SELECT DISTINCT * FROM tV;
SELECT DISTINCT * FROM tB;
SELECT DISTINCT * FROM tD;
SELECT DISTINCT * FROM tT;

-- END TEST >>> 3BASIC0065-3BASIC0072 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0073-3BASIC0096
-- ********************************************************* 
-- TEST:3BASIC0073-3BASIC0096 SELECT DISTINCT one column
-- PASS:3BASIC0073-3BASIC0096 Get 3 rows with the corresponding values

SELECT DISTINCT c1 FROM tI;
SELECT DISTINCT c1 FROM tS;
SELECT DISTINCT c1 FROM tE;
SELECT DISTINCT c1 FROM tC;
SELECT DISTINCT c1 FROM tV;
SELECT DISTINCT c1 FROM tB;
SELECT DISTINCT c1 FROM tD;
SELECT DISTINCT c1 FROM tT;

SELECT DISTINCT c2 FROM tI;
SELECT DISTINCT c2 FROM tS;
SELECT DISTINCT c2 FROM tE;
SELECT DISTINCT c2 FROM tC;
SELECT DISTINCT c2 FROM tV;
SELECT DISTINCT c2 FROM tB;
SELECT DISTINCT c2 FROM tD;
SELECT DISTINCT c2 FROM tT;

SELECT DISTINCT c3 FROM tI;
SELECT DISTINCT c3 FROM tS;
SELECT DISTINCT c3 FROM tE;
SELECT DISTINCT c3 FROM tC;
SELECT DISTINCT c3 FROM tV;
SELECT DISTINCT c3 FROM tB;
SELECT DISTINCT c3 FROM tD;
SELECT DISTINCT c3 FROM tT;

-- END TEST >>> 3BASIC0073-3BASIC0096 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0097-3BASIC0120
-- ********************************************************* 
-- TEST:3BASIC0097-3BASIC0120 SELECT DISTINCT 2 columns
-- PASS:3BASIC0097-3BASIC0120 Get 3 rows with the corresponding values

SELECT DISTINCT c2,c1 FROM tI;
SELECT DISTINCT c2,c1 FROM tS;
SELECT DISTINCT c2,c1 FROM tE;
SELECT DISTINCT c2,c1 FROM tC;
SELECT DISTINCT c2,c1 FROM tV;
SELECT DISTINCT c2,c1 FROM tB;
SELECT DISTINCT c2,c1 FROM tD;
SELECT DISTINCT c2,c1 FROM tT;

SELECT DISTINCT c3,c2 FROM tI;
SELECT DISTINCT c3,c2 FROM tS;
SELECT DISTINCT c3,c2 FROM tE;
SELECT DISTINCT c3,c2 FROM tC;
SELECT DISTINCT c3,c2 FROM tV;
SELECT DISTINCT c3,c2 FROM tB;
SELECT DISTINCT c3,c2 FROM tD;
SELECT DISTINCT c3,c2 FROM tT;

SELECT DISTINCT c1,c3 FROM tI;
SELECT DISTINCT c1,c3 FROM tS;
SELECT DISTINCT c1,c3 FROM tE;
SELECT DISTINCT c1,c3 FROM tC;
SELECT DISTINCT c1,c3 FROM tV;
SELECT DISTINCT c1,c3 FROM tB;
SELECT DISTINCT c1,c3 FROM tD;
SELECT DISTINCT c1,c3 FROM tT;

-- END TEST >>> 3BASIC0097-3BASIC0120 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0121-3BASIC0128
-- ********************************************************* 
-- TEST:3BASIC0121-3BASIC0128 SELECT 3 columns
-- PASS:3BASIC0121-3BASIC0128 Get 3 rows with the corresponding values

SELECT DISTINCT c2,c1,c3 FROM tI;
SELECT DISTINCT c2,c1,c3 FROM tS;
SELECT DISTINCT c2,c1,c3 FROM tE;
SELECT DISTINCT c2,c1,c3 FROM tC;
SELECT DISTINCT c2,c1,c3 FROM tV;
SELECT DISTINCT c2,c1,c3 FROM tB;
SELECT DISTINCT c2,c1,c3 FROM tD;
SELECT DISTINCT c2,c1,c3 FROM tT;

-- END TEST >>> 3BASIC0121-3BASIC0128 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC129-3BASIC0192
-- ********************************************************* 
-- TEST:3BASIC0129-3BASIC0192 SELECT with correlation name
-- PASS:3BASIC0129-3BASIC0192 Get 3 rows with the corresponding values

SELECT DISTINCT * FROM tI AS t12345678901234567;
SELECT DISTINCT * FROM tS AS t12345678901234567;
SELECT DISTINCT * FROM tE AS t12345678901234567;
SELECT DISTINCT * FROM tC AS t12345678901234567;
SELECT DISTINCT * FROM tV AS t12345678901234567;
SELECT DISTINCT * FROM tB AS t12345678901234567;
SELECT DISTINCT * FROM tD AS t12345678901234567;
SELECT DISTINCT * FROM tT AS t12345678901234567;

SELECT DISTINCT c1 FROM tI AS t12345678901234567;
SELECT DISTINCT c1 FROM tS AS t12345678901234567;
SELECT DISTINCT c1 FROM tE AS t12345678901234567;
SELECT DISTINCT c1 FROM tC AS t12345678901234567;
SELECT DISTINCT c1 FROM tV AS t12345678901234567;
SELECT DISTINCT c1 FROM tB AS t12345678901234567;
SELECT DISTINCT c1 FROM tD AS t12345678901234567;
SELECT DISTINCT c1 FROM tT AS t12345678901234567;

SELECT DISTINCT c2 FROM tI AS t12345678901234567;
SELECT DISTINCT c2 FROM tS AS t12345678901234567;
SELECT DISTINCT c2 FROM tE AS t12345678901234567;
SELECT DISTINCT c2 FROM tC AS t12345678901234567;
SELECT DISTINCT c2 FROM tV AS t12345678901234567;
SELECT DISTINCT c2 FROM tB AS t12345678901234567;
SELECT DISTINCT c2 FROM tD AS t12345678901234567;
SELECT DISTINCT c2 FROM tT AS t12345678901234567;

SELECT DISTINCT c3 FROM tI AS t12345678901234567;
SELECT DISTINCT c3 FROM tS AS t12345678901234567;
SELECT DISTINCT c3 FROM tE AS t12345678901234567;
SELECT DISTINCT c3 FROM tC AS t12345678901234567;
SELECT DISTINCT c3 FROM tV AS t12345678901234567;
SELECT DISTINCT c3 FROM tB AS t12345678901234567;
SELECT DISTINCT c3 FROM tD AS t12345678901234567;
SELECT DISTINCT c3 FROM tT AS t12345678901234567;

SELECT DISTINCT c2,c1 FROM tI AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tS AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tE AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tC AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tV AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tB AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tD AS t12345678901234567;
SELECT DISTINCT c2,c1 FROM tT AS t12345678901234567;

SELECT DISTINCT c3,c2 FROM tI AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tS AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tE AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tC AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tV AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tB AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tD AS t12345678901234567;
SELECT DISTINCT c3,c2 FROM tT AS t12345678901234567;

SELECT DISTINCT c1,c3 FROM tI AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tS AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tE AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tC AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tV AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tB AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tD AS t12345678901234567;
SELECT DISTINCT c1,c3 FROM tT AS t12345678901234567;

SELECT DISTINCT c2,c1,c3 FROM tI AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tS AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tE AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tC AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tV AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tB AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tD AS t12345678901234567;
SELECT DISTINCT c2,c1,c3 FROM tT AS t12345678901234567;

-- END TEST >>> 3BASIC0129-3BASIC0192 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC193-3BASIC0248
-- ********************************************************* 
-- TEST:3BASIC0193-3BASIC0248 SELECT with search condition
-- PASS:3BASIC0193-3BASIC0248 Check with DB2 UDB

SELECT DISTINCT * FROM tI AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tS AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tE AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tC AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tV AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tB AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tD AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT * FROM tT AS t12345678901234567 WHERE NOT c3;

SELECT DISTINCT c1 FROM tI AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tS AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tE AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tC AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tV AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tB AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tD AS t12345678901234567 WHERE NOT c1;
SELECT DISTINCT c1 FROM tT AS t12345678901234567 WHERE NOT c1;

SELECT DISTINCT c2 FROM tI AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tS AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tE AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tC AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tV AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tB AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tD AS t12345678901234567 WHERE NOT c2;
SELECT DISTINCT c2 FROM tT AS t12345678901234567 WHERE NOT c2;

SELECT DISTINCT c3 FROM tI AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tS AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tE AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tC AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tV AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tB AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tD AS t12345678901234567 WHERE NOT c3;
SELECT DISTINCT c3 FROM tT AS t12345678901234567 WHERE NOT c3;

SELECT DISTINCT c2,c1 FROM tI AS t12345678901234567 WHERE c1=t12345678901234567.c2;
SELECT DISTINCT c2,c1 FROM tS AS t12345678901234567 WHERE t12345678901234567.c1=c2;
SELECT DISTINCT c2,c1 FROM tE AS t12345678901234567 WHERE tE.c1 = c2;
SELECT DISTINCT c2,c1 FROM tC AS t12345678901234567 WHERE c1 = tE.c2;
SELECT DISTINCT c2,c1 FROM tV AS t12345678901234567 WHERE c2=t12345678901234567.c1;
SELECT DISTINCT c2,c1 FROM tB AS t12345678901234567 WHERE t12345678901234567.c2=c1;
SELECT DISTINCT c2,c1 FROM tD AS t12345678901234567 WHERE tD.c2 = c1;
SELECT DISTINCT c2,c1 FROM tT AS t12345678901234567 WHERE t12345678901234567.c2=c1;

SELECT DISTINCT c3,c2 FROM tI AS t12345678901234567 WHERE c3<>t12345678901234567.c2;
SELECT DISTINCT c3,c2 FROM tS AS t12345678901234567 WHERE t12345678901234567.c3<>c2;
SELECT DISTINCT c3,c2 FROM tE AS t12345678901234567 WHERE tE.c3 <> c2;
SELECT DISTINCT c3,c2 FROM tC AS t12345678901234567 WHERE c3 <> tE.c2;
SELECT DISTINCT c3,c2 FROM tV AS t12345678901234567 WHERE c2<>t12345678901234567.c3;
SELECT DISTINCT c3,c2 FROM tB AS t12345678901234567 WHERE t12345678901234567.c2<>c3;
SELECT DISTINCT c3,c2 FROM tD AS t12345678901234567 WHERE tD.c2 <> c3;
SELECT DISTINCT c3,c2 FROM tT AS t12345678901234567 WHERE t12345678901234567.c2<>c3;

SELECT DISTINCT c2,c1,c3 FROM tI WHERE c1>c3 OR c2>c3;
SELECT DISTINCT c2,c1,c3 FROM tS WHERE c1<>c2 AND c1<>c3;
SELECT DISTINCT c2,c1,c3 FROM tE WHERE c1<5 OR c2>0.00000 OR c3<1.23456;
-- SELECT DISTINCT c2,c1,c3 FROM tC WHERE c1 LIKE c3;
-- c1 LIKE c3 is not allowed
SELECT DISTINCT c2,c1,c3 FROM tC WHERE c3 LIKE '%1%2%3%';
SELECT DISTINCT c2,c1,c3 FROM tV WHERE c1 LIKE '%12' AND c3 LIKE '12%';
SELECT DISTINCT c2,c1,c3 FROM tB;
SELECT DISTINCT c2,c1,c3 FROM tD WHERE c1>c2 AND c2>=c3;
SELECT DISTINCT c2,c1,c3 FROM tT WHERE c1<c2 OR c2<c3;

-- END TEST >>> 3BASIC0193-3BASIC0248 <<< END TEST
-- ********************************************************* 

-- ********************************************************* 
-- 3BASIC0249-3BASIC00293
-- ********************************************************* 
-- TEST:3BASIC0249-3BASIC0293 SELECT with expression
-- PASS:3BASIC0249-3BASIC0293 Check with DB2 UDB

SELECT COUNT(c1),AVG(c1),SUM(c1),MIN(c1),MAX(c1) FROM tI;
SELECT COUNT(c2),AVG(c2),SUM(c2),MIN(c2),MAX(c2) FROM tI;
SELECT COUNT(c3),AVG(c3),SUM(c3),MIN(c3),MAX(c3) FROM tI;

SELECT COUNT(c1),AVG(c1),SUM(c1),MIN(c1),MAX(c1) FROM tS;
SELECT COUNT(c2),AVG(c2),SUM(c2),MIN(c2),MAX(c2) FROM tS;
SELECT COUNT(c3),AVG(c3),SUM(c3),MIN(c3),MAX(c3) FROM tS;

SELECT COUNT(c1),AVG(c1),SUM(c1),MIN(c1),MAX(c1) FROM tE;
SELECT COUNT(c2),AVG(c2),SUM(c2),MIN(c2),MAX(c2) FROM tE;
SELECT COUNT(c3),AVG(c3),SUM(c3),MIN(c3),MAX(c3) FROM tE;

SELECT COUNT(c1) FROM tC;
SELECT COUNT(c2) FROM tC;
SELECT COUNT(c3) FROM tC;

SELECT AVG(c1) FROM tC;
SELECT AVG(c2) FROM tC;
SELECT AVG(c3) FROM tC;

SELECT SUM(c1) FROM tC;
SELECT SUM(c2) FROM tC;
SELECT SUM(c3) FROM tC;

SELECT MIN(c1) FROM tC;
SELECT MIN(c2) FROM tC;
SELECT MIN(c3) FROM tC;

SELECT MAX(c1) FROM tC;
SELECT MAX(c2) FROM tC;
SELECT MAX(c3) FROM tC;

SELECT COUNT(c1) FROM tV;
SELECT COUNT(c2) FROM tV;
SELECT COUNT(c3) FROM tV;

SELECT AVG(c1) FROM tV;
SELECT AVG(c2) FROM tV;
SELECT AVG(c3) FROM tV;

SELECT SUM(c1) FROM tV;
SELECT SUM(c2) FROM tV;
SELECT SUM(c3) FROM tV;

SELECT MIN(c1) FROM tV;
SELECT MIN(c2) FROM tV;
SELECT MIN(c3) FROM tV;

SELECT MAX(c1) FROM tV;
SELECT MAX(c2) FROM tV;
SELECT MAX(c3) FROM tV;

SELECT COUNT(c1) FROM tD;
SELECT COUNT(c2) FROM tD;
SELECT COUNT(c3) FROM tD;

SELECT AVG(c1) FROM tD;
SELECT AVG(c2) FROM tD;
SELECT AVG(c3) FROM tD;

SELECT SUM(c1) FROM tD;
SELECT SUM(c2) FROM tD;
SELECT SUM(c3) FROM tD;

SELECT MIN(c1) FROM tD;
SELECT MIN(c2) FROM tD;
SELECT MIN(c3) FROM tD;

SELECT MAX(c1) FROM tD;
SELECT MAX(c2) FROM tD;
SELECT MAX(c3) FROM tD;

SELECT COUNT(c1) FROM tT;
SELECT COUNT(c2) FROM tT;
SELECT COUNT(c3) FROM tT;

SELECT AVG(c1) FROM tT;
SELECT AVG(c2) FROM tT;
SELECT AVG(c3) FROM tT;

SELECT SUM(c1) FROM tT;
SELECT SUM(c2) FROM tT;
SELECT SUM(c3) FROM tT;

SELECT MIN(c1) FROM tT;
SELECT MIN(c2) FROM tT;
SELECT MIN(c3) FROM tT;

SELECT MAX(c1) FROM tT;
SELECT MAX(c2) FROM tT;
SELECT MAX(c3) FROM tT;

-- ********************************************************* 
-- 3BASIC293-3BASIC0
-- ********************************************************* 
-- TEST:3BASIC0293-3BASIC0 SELECT with LIMIT
-- PASS:3BASIC0293-3BASIC0 Check with DB2 UDB

SELECT * FROM tI LIMIT 1;
SELECT * FROM tS LIMIT 1;
SELECT * FROM tE LIMIT 1;
SELECT * FROM tC LIMIT 1;
SELECT * FROM tV LIMIT 1;
SELECT * FROM tB LIMIT 1;
SELECT * FROM tD LIMIT 1;
SELECT * FROM tT LIMIT 1;

SELECT * FROM tI LIMIT 2;
SELECT * FROM tS LIMIT 2;
SELECT * FROM tE LIMIT 2;
SELECT * FROM tC LIMIT 2;
SELECT * FROM tV LIMIT 2;
SELECT * FROM tB LIMIT 2;
SELECT * FROM tD LIMIT 2;
SELECT * FROM tT LIMIT 2;

SELECT * FROM tI LIMIT 3;
SELECT * FROM tS LIMIT 3;
SELECT * FROM tE LIMIT 3;
SELECT * FROM tC LIMIT 3;
SELECT * FROM tV LIMIT 3;
SELECT * FROM tB LIMIT 3;
SELECT * FROM tD LIMIT 3;
SELECT * FROM tT LIMIT 3;

SELECT COUNT(c1) FROM tI LIMIT 1;
SELECT COUNT(c1) FROM tS LIMIT 1;
SELECT COUNT(c1) FROM tE LIMIT 1;
SELECT COUNT(c1) FROM tC LIMIT 1;
SELECT COUNT(c1) FROM tV LIMIT 1;
SELECT COUNT(c1) FROM tB LIMIT 1;
SELECT COUNT(c1) FROM tD LIMIT 1;
SELECT COUNT(c1) FROM tT LIMIT 1;

SELECT COUNT(c2) FROM tI LIMIT 2;
SELECT COUNT(c2) FROM tS LIMIT 2;
SELECT COUNT(c2) FROM tE LIMIT 2;
SELECT COUNT(c2) FROM tC LIMIT 2;
SELECT COUNT(c2) FROM tV LIMIT 2;
SELECT COUNT(c2) FROM tB LIMIT 2;
SELECT COUNT(c2) FROM tD LIMIT 2;
SELECT COUNT(c2) FROM tT LIMIT 2;

SELECT COUNT(c3) FROM tI LIMIT 3;
SELECT COUNT(c3) FROM tS LIMIT 3;
SELECT COUNT(c3) FROM tE LIMIT 3;
SELECT COUNT(c3) FROM tC LIMIT 3;
SELECT COUNT(c3) FROM tV LIMIT 3;
SELECT COUNT(c3) FROM tB LIMIT 3;
SELECT COUNT(c3) FROM tD LIMIT 3;
SELECT COUNT(c3) FROM tT LIMIT 3;


-- ********************************************************* 
-- 3BASIC293-3BASIC0
-- ********************************************************* 
-- TEST:3BASIC0293-3BASIC0 SELECT with ORDER BY
-- PASS:3BASIC0293-3BASIC0 Check with DB2 UDB

SELECT * FROM tI ORDER BY 1;
SELECT * FROM tS ORDER BY 1;
SELECT * FROM tE ORDER BY 1;
SELECT * FROM tC ORDER BY 1;
SELECT * FROM tV ORDER BY 1;
SELECT * FROM tB ORDER BY 1;
SELECT * FROM tD ORDER BY 1;
SELECT * FROM tT ORDER BY 1;

SELECT * FROM tI ORDER BY 2;
SELECT * FROM tS ORDER BY 2;
SELECT * FROM tE ORDER BY 2;
SELECT * FROM tC ORDER BY 2;
SELECT * FROM tV ORDER BY 2;
SELECT * FROM tB ORDER BY 2;
SELECT * FROM tD ORDER BY 2;
SELECT * FROM tT ORDER BY 2;

SELECT * FROM tI ORDER BY 3;
SELECT * FROM tS ORDER BY 3;
SELECT * FROM tE ORDER BY 3;
SELECT * FROM tC ORDER BY 3;
SELECT * FROM tV ORDER BY 3;
SELECT * FROM tB ORDER BY 3;
SELECT * FROM tD ORDER BY 3;
SELECT * FROM tT ORDER BY 3;

SELECT * FROM tI ORDER BY 1,1;
SELECT * FROM tS ORDER BY 1,1;
SELECT * FROM tE ORDER BY 1,1;
SELECT * FROM tC ORDER BY 1,1;
SELECT * FROM tV ORDER BY 1,1;
SELECT * FROM tB ORDER BY 1,1;
SELECT * FROM tD ORDER BY 1,1;
SELECT * FROM tT ORDER BY 1,1;

SELECT * FROM tI ORDER BY 2,2;
SELECT * FROM tS ORDER BY 2,2;
SELECT * FROM tE ORDER BY 2,2;
SELECT * FROM tC ORDER BY 2,2;
SELECT * FROM tV ORDER BY 2,2;
SELECT * FROM tB ORDER BY 2,2;
SELECT * FROM tD ORDER BY 2,2;
SELECT * FROM tT ORDER BY 2,2;

SELECT * FROM tI ORDER BY 3,3;
SELECT * FROM tS ORDER BY 3,3;
SELECT * FROM tE ORDER BY 3,3;
SELECT * FROM tC ORDER BY 3,3;
SELECT * FROM tV ORDER BY 3,3;
SELECT * FROM tB ORDER BY 3,3;
SELECT * FROM tD ORDER BY 3,3;
SELECT * FROM tT ORDER BY 3,3;

SELECT * FROM tI ORDER BY 2,1;
SELECT * FROM tS ORDER BY 2,1;
SELECT * FROM tE ORDER BY 2,1;
SELECT * FROM tC ORDER BY 2,1;
SELECT * FROM tV ORDER BY 2,1;
SELECT * FROM tB ORDER BY 2,1;
SELECT * FROM tD ORDER BY 2,1;
SELECT * FROM tT ORDER BY 2,1;

SELECT * FROM tI ORDER BY 3,2;
SELECT * FROM tS ORDER BY 3,2;
SELECT * FROM tE ORDER BY 3,2;
SELECT * FROM tC ORDER BY 3,2;
SELECT * FROM tV ORDER BY 3,2;
SELECT * FROM tB ORDER BY 3,2;
SELECT * FROM tD ORDER BY 3,2;
SELECT * FROM tT ORDER BY 3,2;

SELECT * FROM tI ORDER BY 2,1,3,1;
SELECT * FROM tS ORDER BY 2,1,3,1;
SELECT * FROM tE ORDER BY 2,1,3,1;
SELECT * FROM tC ORDER BY 2,1,3,1;
SELECT * FROM tV ORDER BY 2,1,3,1;
SELECT * FROM tB ORDER BY 2,1,3,1;
SELECT * FROM tD ORDER BY 2,1,3,1;
SELECT * FROM tT ORDER BY 2,1,3,1;

-- ********************************************************* 
-- 3BASICxxx-3BASICxxx
-- ********************************************************* 
-- TEST:3BASIC0xxx-3BASICxxx SELECT with GROUP BY
-- PASS:3BASIC0xxx-3BASICxxx Check with DB2 UDB

SELECT * FROM tI GROUP BY c1;
SELECT * FROM tS GROUP BY c1;
SELECT * FROM tE GROUP BY c1;
SELECT * FROM tC GROUP BY c1;
SELECT * FROM tV GROUP BY c1;
SELECT * FROM tB GROUP BY c1;
SELECT * FROM tD GROUP BY c1;
SELECT * FROM tT GROUP BY c1;

SELECT * FROM tI GROUP BY c2;
SELECT * FROM tS GROUP BY c2;
SELECT * FROM tE GROUP BY c2;
SELECT * FROM tC GROUP BY c2;
SELECT * FROM tV GROUP BY c2;
SELECT * FROM tB GROUP BY c2;
SELECT * FROM tD GROUP BY c2;
SELECT * FROM tT GROUP BY c2;

SELECT * FROM tI GROUP BY c3;
SELECT * FROM tS GROUP BY c3;
SELECT * FROM tE GROUP BY c3;
SELECT * FROM tC GROUP BY c3;
SELECT * FROM tV GROUP BY c3;
SELECT * FROM tB GROUP BY c3;
SELECT * FROM tD GROUP BY c3;
SELECT * FROM tT GROUP BY c3;

SELECT * FROM tI GROUP BY c1,c1;
SELECT * FROM tS GROUP BY c1,c1;
SELECT * FROM tE GROUP BY c1,c1;
SELECT * FROM tC GROUP BY c1,c1;
SELECT * FROM tV GROUP BY c1,c1;
SELECT * FROM tB GROUP BY c1,c1;
SELECT * FROM tD GROUP BY c1,c1;
SELECT * FROM tT GROUP BY c1,c1;

SELECT * FROM tI GROUP BY c2,c2;
SELECT * FROM tS GROUP BY c2,c2;
SELECT * FROM tE GROUP BY c2,c2;
SELECT * FROM tC GROUP BY c2,c2;
SELECT * FROM tV GROUP BY c2,c2;
SELECT * FROM tB GROUP BY c2,c2;
SELECT * FROM tD GROUP BY c2,c2;
SELECT * FROM tT GROUP BY c2,c2;

SELECT * FROM tI GROUP BY c3,c3;
SELECT * FROM tS GROUP BY c3,c3;
SELECT * FROM tE GROUP BY c3,c3;
SELECT * FROM tC GROUP BY c3,c3;
SELECT * FROM tV GROUP BY c3,c3;
SELECT * FROM tB GROUP BY c3,c3;
SELECT * FROM tD GROUP BY c3,c3;
SELECT * FROM tT GROUP BY c3,c3;

SELECT * FROM tI GROUP BY c2,c1;
SELECT * FROM tS GROUP BY c2,c1;
SELECT * FROM tE GROUP BY c2,c1;
SELECT * FROM tC GROUP BY c2,c1;
SELECT * FROM tV GROUP BY c2,c1;
SELECT * FROM tB GROUP BY c2,c1;
SELECT * FROM tD GROUP BY c2,c1;
SELECT * FROM tT GROUP BY c2,c1;

SELECT * FROM tI GROUP BY c1,c3;
SELECT * FROM tS GROUP BY c1,c3;
SELECT * FROM tE GROUP BY c1,c3;
SELECT * FROM tC GROUP BY c1,c3;
SELECT * FROM tV GROUP BY c1,c3;
SELECT * FROM tB GROUP BY c1,c3;
SELECT * FROM tD GROUP BY c1,c3;
SELECT * FROM tT GROUP BY c1,c3;

SELECT * FROM tI GROUP BY c2,c3,c1,c3;
SELECT * FROM tS GROUP BY c2,c3,c1,c3;
SELECT * FROM tE GROUP BY c2,c3,c1,c3;
SELECT * FROM tC GROUP BY c2,c3,c1,c3;
SELECT * FROM tV GROUP BY c2,c3,c1,c3;
SELECT * FROM tB GROUP BY c2,c3,c1,c3;
SELECT * FROM tD GROUP BY c2,c3,c1,c3;
SELECT * FROM tT GROUP BY c2,c3,c1,c3;

-- ********************************************************* 
-- 3BASICxxx-3BASICxxx
-- ********************************************************* 
-- TEST:3BASIC0xxx-3BASICxxx SELECT with Arithmetic Expressions
-- PASS:3BASIC0xxx-3BASICxxx Check with DB2 UDB

SELECT c1+c2 FROM tI;
SELECT c1+c2 FROM tS;
SELECT c1+c2 FROM tE;
SELECT c1+c2 FROM tC;
SELECT c1+c2 FROM tV;
SELECT c1+c2 FROM tB;
SELECT c1+c2 FROM tD;
SELECT c1+c2 FROM tT;

SELECT c3+c1 FROM tI;
SELECT c3+c1 FROM tS;
SELECT c3+c1 FROM tE;
SELECT c3+c1 FROM tC;
SELECT c3+c1 FROM tV;
SELECT c3+c1 FROM tB;
SELECT c3+c1 FROM tD;
SELECT c3+c1 FROM tT;

SELECT c3+c2 FROM tI;
SELECT c3+c2 FROM tS;
SELECT c3+c2 FROM tE;
SELECT c3+c2 FROM tC;
SELECT c3+c2 FROM tV;
SELECT c3+c2 FROM tB;
SELECT c3+c2 FROM tD;
SELECT c3+c2 FROM tT;

SELECT c2+c3+c1+c3 FROM tI;
SELECT c2+c3+c1+c3 FROM tS;
SELECT c2+c3+c1+c3 FROM tE;
SELECT c2+c3+c1+c3 FROM tC;
SELECT c2+c3+c1+c3 FROM tV;
SELECT c2+c3+c1+c3 FROM tB;
SELECT c2+c3+c1+c3 FROM tD;
SELECT c2+c3+c1+c3 FROM tT;

SELECT c1+c1+c1+c1 FROM tI;
SELECT c1+c1+c1+c1 FROM tS;
SELECT c1+c1+c1+c1 FROM tE;
SELECT c1+c1+c1+c1 FROM tC;
SELECT c1+c1+c1+c1 FROM tV;
SELECT c1+c1+c1+c1 FROM tB;
SELECT c1+c1+c1+c1 FROM tD;
SELECT c1+c1+c1+c1 FROM tT;

SELECT c2+c2+c2+c2 FROM tI;
SELECT c2+c2+c2+c2 FROM tS;
SELECT c2+c2+c2+c2 FROM tE;
SELECT c2+c2+c2+c2 FROM tC;
SELECT c2+c2+c2+c2 FROM tV;
SELECT c2+c2+c2+c2 FROM tB;
SELECT c2+c2+c2+c2 FROM tD;
SELECT c2+c2+c2+c2 FROM tT;

SELECT c3+c3+c3+c3 FROM tI;
SELECT c3+c3+c3+c3 FROM tS;
SELECT c3+c3+c3+c3 FROM tE;
SELECT c3+c3+c3+c3 FROM tC;
SELECT c3+c3+c3+c3 FROM tV;
SELECT c3+c3+c3+c3 FROM tB;
SELECT c3+c3+c3+c3 FROM tD;
SELECT c3+c3+c3+c3 FROM tT;

SELECT c2-c1 FROM tI;
SELECT c2-c1 FROM tS;
SELECT c2-c1 FROM tE;
SELECT c2-c1 FROM tC;
SELECT c2-c1 FROM tV;
SELECT c2-c1 FROM tB;
SELECT c2-c1 FROM tD;
SELECT c2-c1 FROM tT;

SELECT c3-c2 FROM tI;
SELECT c3-c2 FROM tS;
SELECT c3-c2 FROM tE;
SELECT c3-c2 FROM tC;
SELECT c3-c2 FROM tV;
SELECT c3-c2 FROM tB;
SELECT c3-c2 FROM tD;
SELECT c3-c2 FROM tT;

SELECT c1-c3 FROM tI;
SELECT c1-c3 FROM tS;
SELECT c1-c3 FROM tE;
SELECT c1-c3 FROM tC;
SELECT c1-c3 FROM tV;
SELECT c1-c3 FROM tB;
SELECT c1-c3 FROM tD;
SELECT c1-c3 FROM tT;

SELECT c1-c1+c1-c1+c1 FROM tI;
SELECT c1-c1+c1-c1+c1 FROM tS;
SELECT c1-c1+c1-c1+c1 FROM tE;
SELECT c1-c1+c1-c1+c1 FROM tC;
SELECT c1-c1+c1-c1+c1 FROM tV;
SELECT c1-c1+c1-c1+c1 FROM tB;
SELECT c1-c1+c1-c1+c1 FROM tD;
SELECT c1-c1+c1-c1+c1 FROM tT;

SELECT c1+c1-c1+c1-c1 FROM tI;
SELECT c1+c1-c1+c1-c1 FROM tS;
SELECT c1+c1-c1+c1-c1 FROM tE;
SELECT c1+c1-c1+c1-c1 FROM tC;
SELECT c1+c1-c1+c1-c1 FROM tV;
SELECT c1+c1-c1+c1-c1 FROM tB;
SELECT c1+c1-c1+c1-c1 FROM tD;
SELECT c1+c1-c1+c1-c1 FROM tT;

SELECT c1+c1-c1-c1 FROM tI;
SELECT c1+c1-c1-c1 FROM tS;
SELECT c1+c1-c1-c1 FROM tE;
SELECT c1+c1-c1-c1 FROM tC;
SELECT c1+c1-c1-c1 FROM tV;
SELECT c1+c1-c1-c1 FROM tB;
SELECT c1+c1-c1-c1 FROM tD;
SELECT c1+c1-c1-c1 FROM tT;

SELECT c2-c2+c2-c2+c2 FROM tI;
SELECT c2-c2+c2-c2+c2 FROM tS;
SELECT c2-c2+c2-c2+c2 FROM tE;
SELECT c2-c2+c2-c2+c2 FROM tC;
SELECT c2-c2+c2-c2+c2 FROM tV;
SELECT c2-c2+c2-c2+c2 FROM tB;
SELECT c2-c2+c2-c2+c2 FROM tD;
SELECT c2-c2+c2-c2+c2 FROM tT;

SELECT c2+c2-c2+c2-c2 FROM tI;
SELECT c2+c2-c2+c2-c2 FROM tS;
SELECT c2+c2-c2+c2-c2 FROM tE;
SELECT c2+c2-c2+c2-c2 FROM tC;
SELECT c2+c2-c2+c2-c2 FROM tV;
SELECT c2+c2-c2+c2-c2 FROM tB;
SELECT c2+c2-c2+c2-c2 FROM tD;
SELECT c2+c2-c2+c2-c2 FROM tT;

SELECT c2+c2-c2-c2 FROM tI;
SELECT c2+c2-c2-c2 FROM tS;
SELECT c2+c2-c2-c2 FROM tE;
SELECT c2+c2-c2-c2 FROM tC;
SELECT c2+c2-c2-c2 FROM tV;
SELECT c2+c2-c2-c2 FROM tB;
SELECT c2+c2-c2-c2 FROM tD;
SELECT c2+c2-c2-c2 FROM tT;

SELECT c3-c3+c3-c3+c3 FROM tI;
SELECT c3-c3+c3-c3+c3 FROM tS;
SELECT c3-c3+c3-c3+c3 FROM tE;
SELECT c3-c3+c3-c3+c3 FROM tC;
SELECT c3-c3+c3-c3+c3 FROM tV;
SELECT c3-c3+c3-c3+c3 FROM tB;
SELECT c3-c3+c3-c3+c3 FROM tD;
SELECT c3-c3+c3-c3+c3 FROM tT;

SELECT c3+c3-c3+c3-c3 FROM tI;
SELECT c3+c3-c3+c3-c3 FROM tS;
SELECT c3+c3-c3+c3-c3 FROM tE;
SELECT c3+c3-c3+c3-c3 FROM tC;
SELECT c3+c3-c3+c3-c3 FROM tV;
SELECT c3+c3-c3+c3-c3 FROM tB;
SELECT c3+c3-c3+c3-c3 FROM tD;
SELECT c3+c3-c3+c3-c3 FROM tT;

SELECT c3+c3-c3-c3 FROM tI;
SELECT c3+c3-c3-c3 FROM tS;
SELECT c3+c3-c3-c3 FROM tE;
SELECT c3+c3-c3-c3 FROM tC;
SELECT c3+c3-c3-c3 FROM tV;
SELECT c3+c3-c3-c3 FROM tB;
SELECT c3+c3-c3-c3 FROM tD;
SELECT c3+c3-c3-c3 FROM tT;

SELECT 1.1+1+c1 FROM tI;
SELECT 1.1+1+c1 FROM tS;
SELECT 1.1+1+c1 FROM tE;
SELECT 1.1+1+c1 FROM tC;
SELECT 1.1+1+c1 FROM tV;
SELECT 1.1+1+c1 FROM tB;
SELECT 1.1+1+c1 FROM tD;
SELECT 1.1+1+c1 FROM tT;

SELECT 1.1+1+c2 FROM tI;
SELECT 1.1+1+c2 FROM tS;
SELECT 1.1+1+c2 FROM tE;
SELECT 1.1+1+c2 FROM tC;
SELECT 1.1+1+c2 FROM tV;
SELECT 1.1+1+c2 FROM tB;
SELECT 1.1+1+c2 FROM tD;
SELECT 1.1+1+c2 FROM tT;

SELECT 1.1+1+c3 FROM tI;
SELECT 1.1+1+c3 FROM tS;
SELECT 1.1+1+c3 FROM tE;
SELECT 1.1+1+c3 FROM tC;
SELECT 1.1+1+c3 FROM tV;
SELECT 1.1+1+c3 FROM tB;
SELECT 1.1+1+c3 FROM tD;
SELECT 1.1+1+c3 FROM tT;

SELECT c1+1+1.1 FROM tI;
SELECT c1+1+1.1 FROM tS;
SELECT c1+1+1.1 FROM tE;
SELECT c1+1+1.1 FROM tC;
SELECT c1+1+1.1 FROM tV;
SELECT c1+1+1.1 FROM tB;
SELECT c1+1+1.1 FROM tD;
SELECT c1+1+1.1 FROM tT;

SELECT c2+1+1.1 FROM tI;
SELECT c2+1+1.1 FROM tS;
SELECT c2+1+1.1 FROM tE;
SELECT c2+1+1.1 FROM tC;
SELECT c2+1+1.1 FROM tV;
SELECT c2+1+1.1 FROM tB;
SELECT c2+1+1.1 FROM tD;
SELECT c2+1+1.1 FROM tT;

SELECT c3+1+1.1 FROM tI;
SELECT c3+1+1.1 FROM tS;
SELECT c3+1+1.1 FROM tE;
SELECT c3+1+1.1 FROM tC;
SELECT c3+1+1.1 FROM tV;
SELECT c3+1+1.1 FROM tB;
SELECT c3+1+1.1 FROM tD;
SELECT c3+1+1.1 FROM tT;

-- ********************************************************* 
-- 3BASICxxx-3BASICxxx
-- ********************************************************* 
-- TEST:3BASIC0xxx-3BASICxxx SELECT with some stress test
-- PASS:3BASIC0xxx-3BASICxxx Check with DB2 UDB

SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tI;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tS;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tE;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tC;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tV;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tB;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tD;
SELECT c1,(c1),c1+0,(c1+0),c1-0,(c1-0),0+c1,(0+c1),0-c1,(0-c1),c1-c1,c1/c1,c1*1,1*c1 FROM tT;

SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tI;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tS;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tE;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tC;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tV;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tB;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tD;
SELECT c2,(c2),c2+0,(c2+0),c2-0,(c2-0),0+c2,(0+c2),0-c2,(0-c2),c2-c2,c2/c2,c2*1,1*c2 FROM tT;

SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tI;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tS;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tE;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tC;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tV;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tB;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tD;
SELECT c3,(c3),c3+0,(c3+0),c3-0,(c3-0),0+c3,(0+c3),0-c3,(0-c3),c3-c3,c3/c3,c3*1,1*c3 FROM tT;
